@@ -83,9 +83,8 @@ def format(thing=None, **kwargs):
         'plaintext' (default): Output just text
 
         'darkbg', 'darkbg2', 'darkbg3', 'lightbg', 'lightbg2', 'lightbg3':
-            Output ANSI-colors, for use with terminals that support 256
-            colors or notebooks (or something like the `ansi2html` package,
-            to create colorful log files)
+            Enable colors, for use in terminals that support 256 ansi
+            colors or in jupyter notebooks (or even with `ansi2html`)
 
     source_lines: int or 'all'
         Select how much source code context will be shown.
@@ -107,6 +106,10 @@ def format(thing=None, **kwargs):
         Maximum number of characters to be used for each variable value.
         Default: 500
 
+    line_wrap: int (default 60)
+        Limit how many columns are available to print each variable
+        (excluding its name). Set to 0 or False to disable wrapping.
+
     suppressed_paths: list of regex patterns
         Set less verbose formatting for frames whose code lives in certain paths
         (e.g. library code). Files whose path matches any of the given regex
@@ -118,6 +121,11 @@ def format(thing=None, **kwargs):
         Example: To hide numpy internals from the traceback, set
         `suppressed_paths=[r"lib/python.*/site-packages/numpy"]`
 
+    suppressed_exception_types: list of exception classes
+        Show less verbose formatting for exceptions in this list.
+        By default, this list is `[KeyboardInterrupt]`. Set to `[]`
+        to force verbose formatting even on a keyboard interrupt.
+
     reverse: bool
         List the innermost frame first.
 
@@ -143,7 +151,7 @@ def format(thing=None, **kwargs):
 
 
 @_guess_thing
-def show(thing=None, file=sys.stderr, **kwargs):
+def show(thing=None, file='stderr', **kwargs):
     """
     Print the traceback of an exception or a frame's call stack
 
@@ -215,15 +223,19 @@ def set_excepthook(**kwargs):
     """
     Set sys.excepthook to print a detailed traceback for any uncaught exception.
 
+    See `format()` for available kwargs.
+
     Examples:
+    ----
 
+    Print to stdout instead of stderr:
     ```
-    set_excepthook(file='stdout')    # print to stdout instead of stderr
-
+    set_excepthook(file='stdout')
     ```
 
+    Enable color output:
     ```
-    set_excepthook(style='darkbg')  # do ansi colors
+    set_excepthook(style='darkbg') # or e.g. 'lightbg' (for more options see `format`)
     ```
 
     If running under Ipython, this will, with a heavy heart, attempt to monkey
@@ -236,7 +248,7 @@ def set_excepthook(**kwargs):
     Params
     --
     **kwargs:
-        See `show`
+        See `show` and `format`
     """
     if _is_running_in_ipython():
         _patch_ipython_excepthook(**kwargs)
