@@ -17,16 +17,6 @@ def get_formatter(style, **kwargs):
         return ColorfulFrameFormatter(style, **kwargs)
 
 
-def inspect_frames(frames):
-    for fi in frames:
-        if isinstance(fi, ex.FrameInfo):
-            yield fi
-        elif isinstance(fi, types.FrameType):
-            yield ex.get_info(fi)
-        else:
-            raise ValueError("Expected a frame or a FrameInfo tuple, got %r" % fi)
-
-
 def format_summary(frames, style='plaintext', source_lines=1, reverse=False,
                    **kwargs):
     """
@@ -40,7 +30,7 @@ def format_summary(frames, style='plaintext', source_lines=1, reverse=False,
                                       show_signature=False,
                                       show_vals=False)
 
-    frame_msgs = [minimal_formatter(fi) for fi in inspect_frames(frames)]
+    frame_msgs = [minimal_formatter(frame) for frame in frames]
     if reverse:
         frame_msgs = reversed(frame_msgs)
 
@@ -49,7 +39,7 @@ def format_summary(frames, style='plaintext', source_lines=1, reverse=False,
 
 def format_stack(frames, style='plaintext', source_lines=5,
                  show_signature=True, show_vals='like_source',
-                 truncate_vals=500, reverse=False, suppressed_paths=None):
+                 truncate_vals=500, line_wrap=60, reverse=False, suppressed_paths=None):
     """
     Render a list of frames (or FrameInfo tuples)
 
@@ -69,6 +59,7 @@ def format_stack(frames, style='plaintext', source_lines=5,
                                       show_signature=show_signature,
                                       show_vals=show_vals,
                                       truncate_vals=truncate_vals,
+                                      line_wrap=line_wrap,
                                       suppressed_paths=suppressed_paths)
 
     verbose_formatter = get_formatter(style=style,
@@ -76,23 +67,24 @@ def format_stack(frames, style='plaintext', source_lines=5,
                                       show_signature=show_signature,
                                       show_vals=show_vals,
                                       truncate_vals=truncate_vals,
+                                      line_wrap=line_wrap,
                                       suppressed_paths=suppressed_paths)
 
     frame_msgs = []
-    is_boring = False
     parent_is_boring = True
-    for fi in inspect_frames(frames):
+    for frame in frames:
+        fi = ex.get_info(frame)
         is_boring = match(fi.filename, suppressed_paths)
         if is_boring:
             if parent_is_boring:
-                frame_msgs.append(minimal_formatter(fi))
+                formatter = minimal_formatter
             else:
-                frame_msgs.append(reduced_formatter(fi))
-            parent_is_boring = True
-
+                formatter = reduced_formatter
         else:
-            frame_msgs.append(verbose_formatter(fi))
-            parent_is_boring = False
+            formatter = verbose_formatter
+
+        parent_is_boring = is_boring
+        frame_msgs.append(formatter(fi))
 
     if reverse:
         frame_msgs = reversed(frame_msgs)
@@ -110,7 +102,7 @@ def format_stack_from_frame(fr, add_summary=False, **kwargs):
     """
     stack = []
     while fr is not None:
-        stack.append(ex.get_info(fr))
+        stack.append(fr)
         fr = fr.f_back
     stack = reversed(stack)
 
@@ -118,18 +110,20 @@ def format_stack_from_frame(fr, add_summary=False, **kwargs):
 
 
 def format_exc_info(etype, evalue, tb, style='plaintext', add_summary='auto',
-                    reverse=False, **kwargs):
+                    reverse=False, suppressed_exceptions=[KeyboardInterrupt],
+                    **kwargs):
     """
     Format an exception traceback, including the exception message
 
-    keyword args like stackprinter.format()
+    see stackprinter.format() for docs about the keyword arguments
     """
     msg = ''
     try:
-        # First, recursively format any chained exceptions (exceptions during whose handling
-        # the given one happened).
-        # TODO: refactor this whole messy function to return a more... structured datastructure
-        # before assembling a string, so that e.g. a summary of the whole chain can be shown at
+        # First, recursively format any chained exceptions (exceptions
+        # during whose handling the given one happened).
+        # TODO: refactor this whole messy function to return a
+        # more... structured datastructure before assembling a string,
+        # so that e.g. a summary of the whole chain can be shown at
         # the end.
         context = getattr(evalue, '__context__', None)
         cause = getattr(evalue, '__cause__', None)
@@ -162,32 +156,44 @@ def format_exc_info(etype, evalue, tb, style='plaintext', add_summary='auto',
                 msg += clr % chain_hint
 
         # Now, actually do some formatting:
-        msgs = []
+        parts = []
         if tb:
             frameinfos = [ex.get_info(tb_) for tb_ in _walk_traceback(tb)]
-            stack_msg = format_stack(frameinfos, style=style, reverse=reverse, **kwargs)
-            msgs.append(stack_msg)
+            if (suppressed_exceptions and
+                issubclass(etype, tuple(suppressed_exceptions))):
+                summary = format_summary(frameinfos, style=style,
+                                         reverse=reverse, **kwargs)
+                parts = [summary]
+            else:
+                whole_stack = format_stack(frameinfos, style=style,
+                                           reverse=reverse, **kwargs)
+                parts.append(whole_stack)
 
-            if add_summary == 'auto':
-                add_summary = stack_msg.count('\n') > 50
+                if add_summary == 'auto':
+                    add_summary = whole_stack.count('\n') > 50
 
-            if add_summary:
-                summ = format_summary(frameinfos, style=style, reverse=reverse, **kwargs)
-                summ += '\n'
-                msgs.append('---- (full traceback below) ----\n\n' if reverse else
-                            '---- (full traceback above) ----\n')
-                msgs.append(summ)
+                if add_summary:
+                    summary = format_summary(frameinfos, style=style,
+                                             reverse=reverse, **kwargs)
+                    summary += '\n'
+                    parts.append('---- (full traceback below) ----\n\n' if reverse else
+                                 '---- (full traceback above) ----\n')
+                    parts.append(summary)
 
         exc = format_exception_message(etype, evalue, style=style)
-        msgs.append('\n\n' if reverse else '')
-        msgs.append(exc)
+        parts.append('\n\n' if reverse else '')
+        parts.append(exc)
 
         if reverse:
-            msgs = reversed(msgs)
+            parts = reversed(parts)
 
-        msg += ''.join(msgs)
+        msg += ''.join(parts)
 
     except Exception as exc:
+        import os
+        if 'PY_STACKPRINTER_DEBUG' in os.environ:
+            raise
+
         our_tb = traceback.format_exception(exc.__class__,
                                             exc,
                                             exc.__traceback__,
